summaryrefslogtreecommitdiffstats
path: root/kmobile/devices/skeleton/skeleton.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmobile/devices/skeleton/skeleton.h')
-rw-r--r--kmobile/devices/skeleton/skeleton.h17
1 files changed, 9 insertions, 8 deletions
diff --git a/kmobile/devices/skeleton/skeleton.h b/kmobile/devices/skeleton/skeleton.h
index de57947a..8d5c3db4 100644
--- a/kmobile/devices/skeleton/skeleton.h
+++ b/kmobile/devices/skeleton/skeleton.h
@@ -17,8 +17,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#ifndef LIBKMOBILE_SKELETON_H
@@ -29,26 +29,27 @@
class KMobileSkeleton : public KMobileDevice
{
Q_OBJECT
+ TQ_OBJECT
public:
KMobileSkeleton( TQObject *obj=0, const char *name=0, const TQStringList &args=TQStringList() );
~KMobileSkeleton();
// createObject needs to be reimplemented by every KMobileDevice driver
- TQObject *createObject( TQObject *parent=0, const char *name=0,
- const char *classname="TQObject", const TQStringList &args=TQStringList() );
+ TQObject *createObject( TQObject *tqparent=0, const char *name=0,
+ const char *classname=TQOBJECT_OBJECT_NAME_STRING, const TQStringList &args=TQStringList() );
// connect, disconnect and current status
- bool connectDevice(TQWidget *parent);
- bool disconnectDevice(TQWidget *parent);
+ bool connectDevice(TQWidget *tqparent);
+ bool disconnectDevice(TQWidget *tqparent);
- // returns true, if this device is read-only (default: false)
+ // returns true, if this tqdevice is read-only (default: false)
bool isReadOnly() const;
// you may provide your own icon() implementation to display
// an appropriate Pixmap (e.g. a Palm Pilot or a Zaurus image).
TQString iconFileName() const;
- TQString deviceUniqueID();
+ TQString tqdeviceUniqueID();
/*
* Addressbook / Phonebook support